pub struct I3c<'d, M: Mode> { /* private fields */ }Expand description
I3C controller driver.
Implementations
Sourceimpl<'d, M: Mode> I3c<'d, M>
impl<'d, M: Mode> I3c<'d, M>
Sourcepub fn blocking_read(
&mut self,
address: u8,
read: &mut [u8],
bus_type: BusType,
) -> Result<(), IOError>
pub fn blocking_read( &mut self, address: u8, read: &mut [u8], bus_type: BusType, ) -> Result<(), IOError>
Read from address into buffer blocking caller until done.
Sourceimpl<'d> I3c<'d, Async>
impl<'d> I3c<'d, Async>
Sourcepub fn new_async<T: Instance>(
peri: Peri<'d, T>,
scl: Peri<'d, impl SclPin<T>>,
sda: Peri<'d, impl SdaPin<T>>,
_irq: impl Binding<T::Interrupt, InterruptHandler<T>> + 'd,
config: Config,
) -> Result<Self, SetupError>
pub fn new_async<T: Instance>( peri: Peri<'d, T>, scl: Peri<'d, impl SclPin<T>>, sda: Peri<'d, impl SdaPin<T>>, _irq: impl Binding<T::Interrupt, InterruptHandler<T>> + 'd, config: Config, ) -> Result<Self, SetupError>
Create a new asynchronous instance of the I3C controller bus driver.
Any external pin will be placed into Disabled state upon Drop.
Sourceimpl<'d> I3c<'d, Dma<'d>>
impl<'d> I3c<'d, Dma<'d>>
Sourcepub fn new_async_with_dma<T: Instance>(
peri: Peri<'d, T>,
scl: Peri<'d, impl SclPin<T>>,
sda: Peri<'d, impl SdaPin<T>>,
tx_dma: Peri<'d, impl Channel>,
rx_dma: Peri<'d, impl Channel>,
_irq: impl Binding<T::Interrupt, InterruptHandler<T>> + 'd,
config: Config,
) -> Result<Self, SetupError>
pub fn new_async_with_dma<T: Instance>( peri: Peri<'d, T>, scl: Peri<'d, impl SclPin<T>>, sda: Peri<'d, impl SdaPin<T>>, tx_dma: Peri<'d, impl Channel>, rx_dma: Peri<'d, impl Channel>, _irq: impl Binding<T::Interrupt, InterruptHandler<T>> + 'd, config: Config, ) -> Result<Self, SetupError>
Create a new async instance of the I3C Controller bus driver with DMA support.
Any external pin will be placed into Disabled state upon Drop, additionally, the DMA channel is disabled.
Sourceimpl<'d, M: AsyncMode> I3c<'d, M>where
Self: AsyncEngine,
impl<'d, M: AsyncMode> I3c<'d, M>where
Self: AsyncEngine,
Sourcepub fn async_read<'a>(
&'a mut self,
address: u8,
read: &'a mut [u8],
bus_type: BusType,
) -> impl Future<Output = Result<(), IOError>> + 'a
pub fn async_read<'a>( &'a mut self, address: u8, read: &'a mut [u8], bus_type: BusType, ) -> impl Future<Output = Result<(), IOError>> + 'a
Read from address into buffer asynchronously.